## Optimal Force–Velocity Profile in Ballistic Movements—Altius: Citius or Fortius?

PIERRE SAMOZINO \[1\], ENRICO REJC \[2\], PIETRO ENRICO DI PRAMPERO \[2\], ALAIN BELLI \[3\],
and JEAN-BENOI \[ˆ\] T MORIN \[3\]

1Laboratory of Exercise Physiology (EA4338), University of Savoy, Le Bourget du Lac, FRANCE;
2Department of Biomedical Sciences and Technologies, University of Udine, Udine, ITALY; and
3Laboratory of Exercise Physiology (EA4338), University of Lyon, Saint Etienne, FRANCE

ABSTRACT

SAMOZINO, P., E. REJC, P. E. DI PRAMPERO, A. BELLI, and J.-B. MORIN. Optimal Force–Velocity Profile in Ballistic Move
ments—Altius: Citius or Fortius? Med. Sci. Sports Exerc., Vol. 44, No. 2, pp. 313–322, 2012. Purpose: The study’s purpose was to
determine the respective influences of the maximal power (P;max \[) and the force–velocity (\]\[F\]\[–\]\[v\]\[) mechanical profile of the lower limb\]

neuromuscular system on performance in ballistic movements. Methods: A theoretical integrative approach was proposed to express

obtained on 14 subjects during lower limb ballistic inclined push-offs and (ii) simulated to quantify the respective influence ofballistic performance as a mathematical function of P;max \[and\]\[ F\]\[–\]\[v\]\[ profile. This equation was (i) validated from experimental data\] P;max \[and\]

F–v profile on performance. Results: The bias between performances predicted and obtained from experimental measurements was

4%–7%, confirming the validity of the proposed theoretical approach. Simulations showed that ballistic performance was mostly influenced not only by P;max \[but also by the balance between force and velocity capabilities as described by the\]\[ F\]\[–\]\[v\]\[ profile. For each indi-\]

vidual, there is an optimal F–v profile that maximizes performance, whereas unfavorable F–v balances lead to differences in performance up

(limb extension range,to 30% for a given P P;;max \[. This optimal\]\[) and on the afterload involved in the movement (inertia, inclination). The lower the afterload, the more the opti-\]\[ F\]\[–\]\[v\]\[ profile, which can be accurately determined, depends on some individual characteristics\]

;

;

;

;

;

;

(limb extension range, Pmax \[) and on the afterload involved in the movement (inertia, inclination). The lower the afterload, the more the opti-\]

mal F–v profile is oriented toward velocity capabilities and the greater the limitation of performance imposed by the maximal velocity of

lower limb extension. Conclusions: High ballistic performances are determined by both maximization of the power output capabilities and

optimization of the F–v mechanical profile of the lower limb neuromuscular system. Key Words: MAXIMAL POWER, JUMPING

PERFORMANCE, LOWER EXTREMITY EXTENSION, INCLINED PUSH-OFF, EXPLOSIVE STRENGTH, MUSCLE FUNCTION

allistic movements, notably jumping, have often shortest time during a push-off. From Newton’s second
been investigated to better understand the mechani- law of motion, the velocity reached by the body center of

# B cal limits of skeletal muscle function in vivo, be it

allistic movements, notably jumping, have often
been investigated to better understand the mechani# B cal limits of skeletal muscle function in vivo, be it

in animals (19,23) or in humans (6,9,20). One of the main
questions scientists, coaches, or athletes ask when exploring factors for optimizing ballistic performance is which
mechanical quality of the neuromuscular system is more
important: ‘‘force’’ or ‘‘velocity’’ mechanical capability?

Ballistic movements may be defined as maximal movements aiming to accelerate a moving mass as much as possible, that is, to reach the highest possible velocity in the

Address for correspondence: Pierre Samozino, Ph.D., Laboratoire de Physiologie de l’Exercice, Universite´ de Saint-E \[´\] tienne, Me´decine du sport et
Myologie - Centre Hospitalier Universitaire Bellevue, 42055 Saint-E \[´\] tienne
Cedex 02, France; E-mail: <pierre.samozino@univ-savoie.fr>.
Submitted for publication November 2010.
Accepted for publication July 2011.

Supplemental digital content is available for this article. Direct URL
citations appear in the printed text and are provided in the HTML and PDF
versions of this article on the journal’s Web site (\<www.acsm-msse.org>).

0195-9131/12/4402-0313/0

MEDICINE & SCIENCE IN SPORTS & EXERCISE�
Copyright � 2012 by the American College of Sports Medicine

DOI: 10.1249/MSS.0b013e31822d757a

shortest time during a push-off. From Newton’s second
law of motion, the velocity reached by the body center of
mass (CM) at the end of a push-off (or takeoff velocity, vTO)
directly depends on the mechanical impulse developed in
the movement direction (22,26,42). Because the ability to
develop a high impulse cannot be considered as a mechanical property of the neuromuscular system, the issue is to
identify which mechanical capabilities of the lower limbs
determine the impulse. Developing a high impulse during a
lower limb push-off and, in turn, accelerating body mass as
much as possible have often been assumed to depend on
power capabilities of the neuromuscular system involved in
the movement (14,19,26,29,36,40,43). This explains the
wide interest of sports performance practitioners in improving muscular power (9,10,12,14,27). On this basis,maximal power output (P;max \[) may be improved by in-\]

creasing the ability to develop high levels of force at low
velocities (force capabilities or strength) and/or lower levels
of force at high velocities (velocity capabilities) (10,11,27).
The best strategy continues to be an everlasting source of
interest and debate (5,10–12,14,29).

The overall dynamic mechanical capabilities of the lower
limb neuromuscular system have been well described by
inverse linear force–velocity (F–v) and parabolic power–
velocity (P–v) relationships during various types of multijoint

;

313

Copyright © 2012 by the American College of Sports Medicine. Unauthorized reproduction of this article is prohibited.

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

concentric extension movements (3,33,35,40,43). These relationships describe the changes in external force generation
and power output with increasing movement velocity and
may be summarized through three typical variables: the the-oretical maximal force at null velocity (F;0 \[), the\]\[ P\] ;max \[the\]

lower limbs can produce over one extension, and the theoretical maximal velocity at which lower limbs can extend
during one extension under zero load (v \[Y\] 0 \[). These three pa-\]

rameters represent the maximal mechanical capabilities of
lower limbs to generate external force, power output, and
extension velocity, respectively. Because they characterize
the mechanical limits of the entire neuromuscular function,
they encompass individual muscle mechanical properties
(e.g., intrinsic F–v and length–tension relationships, rate of
force development), some morphological factors (e.g., crosssectional area, fascicle length, pennation angle, tendon properties), and neural mechanisms (e.g., motor unit recruitment,
firing frequency, motor unit synchronization, intermuscularcoordination) (9). Graphically, F;0 \[and\]\[ v\]\[Y\] 0 \[correspond to the\]

force axis and velocity axis intercepts of the linearrespectively, and P;max \[corresponds to the apex of the para-\] F–v curve,

bolic P–v relationship. Under these conditions, the relationship among these three parameters can be described by the
following mathematical equation (41):

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

0 \[), the\]\[ P\]

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

0 \[and\]\[ v\]\[Y\]

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

Pmax \[and\]\[ F\]\[–\]\[v\]\[ profile on performance in ballistic lower limb\]

movements. Moreover, force and velocity contributions to
power output depend on the load involved (10,14). Consequently, the secondary aim of this study was to investigate
whether the effects of the F–v profile on ballistic performances (if any) depend on the afterloads (additional loads
and/or push-off orientation against gravity) involved in
the movement. To achieve these aims, the aforementioned
theoretical analysis was compared with experimental measurements during jumping.

THEORETICAL BACKGROUND

This section is devoted to an analysis of ballistic performance through maximal jumps at different push-off
angles. The entire lower limb neuromuscular system is
considered as a force generator characterized by an inverse
linear F–v relationship and a given range of motion. The
maximal jumping performance can be well represented by
the maximal vTO (vTOmax) of the body CM. As detailed in the
recent theoretical integrative approach, jumping performance can be expressed as a function of some mechanical
characteristics of lower limbs. In this approach mentioned
above (see Samozino et al. \[37\]), vTOmax can be expressed
as follows:

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

vTOmax ¼ hPO

P�max ¼ **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

F�0�v0 ½1�

4 **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

;

f
**f** i fY **f** i f2 **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f**
F \[2\] \[Y\]

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

1 ½2�

A

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

ðF \[Y\] 0jgsin>Þ

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** Y

F 0

2v ~~\[Y\]~~ 0

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

0

@

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

s

**f** Y **f** 2 **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**
F 0

4 ~~\[Y\]~~ v \[2\]

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

þ \[2\]

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

Consequently, two athletes with similar Pmax \[could theo-\]

retically present differentferent combinations of F; F0 \[and\] –v mechanical profiles, i.e., dif- \[ v\]\[Y\] 0 \[. The issue is therefore to\]

determine whether theperformances independently of F–v profile may influence ballistic P;max \[. In other words, is it\]

preferable to be ‘‘strong’’ or ‘‘fast’’ to reach the highest performance in ballistic movements? Such an analysis might
provide greater insight into the relationship between mechanical properties of the neuromuscular system and functional performance, either to further explore animal motor
behaviors (19,20) or to program athletic training in humans,
as underlined in recent reviews (10,12,14).

The effects of the F–v mechanical profile on ballistic performance have been experimentally approached only through
studies led in athletes with different training backgrounds
(40,43), through different training protocols (5,7,11,16,27),
or both (4,8). However, in these studies, the variousprofiles of athletes were also associated with various P F;max–v

values among subjects, making it impossible to identify
the sole effect of the F–v profile. The influence of force
and velocity capabilities on jumping performance has been
recently addressed through a theoretical integrative approach
mathematically expressing the maximal jump height an indi-vidual can reach as a function ofwere not independent from possible effects ofthe observed positive effects of F F;;0 0 \[and\]\[and\]\[ v\]\[ v\]\[Y\]\[Y\] 00 \[on performance\] P \[(37). However,\] ;max \[, the latter\]

being overlooked.

On the basis of this theoretical approach, the main aim
of this study was to determine the respective influences of

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

Consequently, two athletes with similar P

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

0

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

j

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

hPO

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

0 \[and\]\[ v\]\[Y\]

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

where g is the gravitational acceleration (9.81 mIs \[j\]\[2\] ), > is
the push-off angle with respect to the horizontal (-), hPO
is the distance covered by the CM during push-off corresponding to the extension range of lower limbs (m), andF;0 \[(N\]\[I\]\[kg\]\[j\]\[1\]\[ of moving mass) and\]\[ v\]\[Y\] 0 \[(m\]\[I\]\[s\]\[j\]\[1\]\[) are the maxi-\]

mal force at theoretical null velocity and the theoretical
maximal unloaded velocity of lower limbs, respectively.
The push-off angle >, assumed to be the same as the axis of
the force developed, is considered constant over the entire
push-off. In equation 2, the afterload opposing in motion
is taken into account through inertia (i.e., the movingmass present here in the normalization of F;0 \[) and gravity\]

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

0 \[(N\]\[I\]\[kg\]\[j\]\[1\]\[ of moving mass) and\]\[ v\]\[Y\]

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

mass present here in the normalization of F 0 \[) and gravity\]

(g � sin >, i.e., the component of the gravity opposed to the
movement).

sented by the ratio betweenThe F–v mechanical profile of lower limbs can be repre- F;0 \[and\]\[ v\]\[Y\] 0 \[, i.e., by the slope of\]

the linear F–v relationship (SFv) given by the following
equation:

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

0 \[and\]\[ v\]\[Y\]

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

FY0

SFv ¼ j ~~Y~~

v0

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

½3�

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

0 \[and\]\[ v\]\[Y\]

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

0 \[and\]\[ v\]\[Y\]

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

(with the force graphically represented on the vertical axis of
the F–v relationship).

Thus, the lower the SFv, the steeper the F–v relationship and the higher the force capabilities compared withvelocity ones (7). Note that SFv and P;max \[are theorized to be\]

independent.

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

314 Official Journal of the American College of Sports Medicine <http://www.acsm-msse.org>

Copyright © 2012 by the American College of Sports Medicine. Unauthorized reproduction of this article is prohibited.

Substituting equation 3 in equation 2 gives the following:

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

0

@

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

f
**f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f**
S \[2\] \[2\] \[Y\]

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

þ \[S\]\[Fv\]

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

2

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

1

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

½4�
A

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

vTOmax ¼ hPO

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

s

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

Fv

\[2\]
4 \[þ\] h

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

hPO

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

ðF \[Y\] 0jgsin>Þ

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

expressed as a function ofOn the other hand, from equations 1 and 3, P; \[and\]\[ S\]\[Fv\]\[:\] F 0 \[can be\]

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

On the other hand, from equations 1 and 3, F

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

max \[and\]\[ S\]\[Fv\]\[:\]

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** ½5�

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

Y
F 0 ¼ **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

f
pj **f** i f **f** i f4 **f** i fP **f** i f \[Y\] **f** i fmax **f** i f **f** i f **f** i fS **f** i fFv **f** i f **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

Vicenza, Italy) mounted on the back of the main frame. Force

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** and velocity analog outputs were sampled at a frequency of

1000 Hz using a data acquisition system (MP100; BIOPAC
Systems, Inc., Goleta, CA). The instantaneous power was calculated from the product of instantaneous force and velocity
values. Data were processed using the AcqKnowledge software (BIOPAC Systems, Inc.). An electric motor, positioned

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** in front of the carriage seat, allowed us to impose known

braking forces, acting along the direction of motion. The motor, controlled by a personal computer, was linked to the seat

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** by a chain, its braking action initiating immediately at the

**f** **f** **f** **f** **f** **f** **f** **f** **f**

onset of the subject’s push. The braking force of the motor,
ranging from about 200 to 2300 N, was set using a custombuilt LabVIEW program (National Instruments, Austin, TX).

For each test, the subject was seated on the carriage seat,
secured by a safety belt tightened around the shoulders and
abdomen, with the arms on handlebars. The starting posi
tion, set with feet on the force plates and knees flexed at 90,
was fixed thanks to adjustable blocks positioned on the rail
of the EXER to prevent the downward movement of the
carriage seat and, in turn, any countermovement.

F–v relationships of lower limb neuromuscular
system. To determine individual F–v relationships, each
subject performed horizontal maximal lower limb extension
against seven randomized motor braking forces: 0%, 40%,
80%, 120%, 160%, 200%, and 240% of the subject’s body
weight. The condition without braking force (0% of body
weight) was performed with the motor chain disconnected
from the carriage seat. For each trial, subjects were asked
to extend their lower limbs as fast as possible. Two trials,
separated by 2 min of recovery, were completed at eachbraking force. Mean force (FY), velocity (vY), and power (PY)

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

Substituting equation 5 in equation 4 gives the following:

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

f
S **f** i f \[2\] **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f \[2\] **f** i f **f** i f **f** i fi f **f** **f** i f **f** i f **f** i ff **f** i f **f** **f** i f **f** \[Y\] **f** i f **f** **f** i f **f** **f** i f **f** **f** i f **f** **f** i f **f** **f** i f **f** i f **f** **f** **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** i f **f** iffi

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** þ \[S\]\[Fv\]

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

2

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** 1

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** jgsin>Þ

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

vTOmax ¼ hPO **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

0 **f** **f** **f** **f** **f** **f** **f** **f** **f**

@

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

f
**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

s **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

Fv \[2\] **f** **f** **f** **f** **f** **f** **f** **f** **f**
4 \[þ\] h

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

hPO

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

ð2 **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** f **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

pj **f** i f **f** i fP \[Y\] **f** i fmax **f** i f **f** i f **f** i fS **f** i fFv **f** i f **f** i ffi

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** ½6�

~~A~~

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

tion ofConsequently, P;max \[,\]\[ S\] v \[Fv\] TO \[, and\] max can also be expressed as a func- \[ h\]\[PO\]\[. Equation 6 is true for\]

j
hPO 9 0, P \[Y\] max 9 gsin> \[2\] = 4 SFv, and SFv G jgsin> \[2\] =4 P \[Y\] max
(see appendices, Supplemental Digital Content 1a,
<http://links.lww.com/MSS/A114>, for details on the computations of these values). In the present study, equation 6
was (i) validated from experimental measurements and (ii)simulated to analyze the respective influences of P;max \[and\]

SFv on jumping performance.

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

METHODS USED IN THE EXPERIMENTAL
VALIDATION

Subjects and experimental protocol. Fourteen subjects (age = 26.3 T 4.5 yr, body mass = 83.9 T 18.3 kg, stature
= 1.81 T 0.07 m) gave their written informed consent to
participate in this study, which was approved by the local
ethical committee and in agreement with the Declaration of
Helsinki. All subjects practiced physical activities including
explosive efforts (e.g., basketball, rugby, soccer); eight of
them were rugby players (four played in the Italian first
league). After a 10-min warm-up and a brief familiarization
with the laboratory equipment, each subject performed two
series of maximal lower limb push-offs: (i) horizontal extensions with different resistive forces allowing us to determine F–v relationships of the lower limbs and (ii) inclined
jumps used to compare experimental performances with
theoretical predictions.

Tests were realized on the Explosive Ergometer
(EXER, see Figure, Supplemental Digital Content 2,
<http://links.lww.com/MSS/A115>, for a schematic view of
the EXER) consisting of a metal frame supporting one rail
on which a seat, fixed on a carriage, was free to move
(for more details, see Rejc et al. \[34\]). The total moving
mass (seat + carriage) was 31.6 kg. The main frame could be
inclined up to a maximum angle of 30- with respect to the
horizontal. The subject could therefore accelerate himself or
herself and the carriage seat backward by pushing on two
force plates (LAUMAS PA 300; Parma, Italy) positioned
perpendicular to the rail, the output of which was independent
of the point of application of the force within a wide area. The
velocity of the carriage seat along the direction of motion was
continuously recorded by a wire tachometer (LIKA SGI,

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

braking force. Mean force (FY), velocity (vY), and power (PY)

for the best trial of each condition were determined from the

averages of instantaneous values over the entire push-off
phase. The push-off began when the velocity signal increased and ended when the force signal (if takeoff) or the
velocity signal (if no takeoff) fell to zero. As previously
suggested (3,33,43), F–v relationships were determined by
least squares linear regressions. Because P–v relationships
are derived from the product of force and velocity, they were
logically described by second-degree polynomial functions.;
F–v curves were extrapolated to obtain F 0 \[(then normalized\]

to total moving mass, i.e., body + carriage seat mass) and v \[Y\] 0 \[,\]

which correspond to the intercepts of the F–v curve with the
force and velocity axis, respectively. According to equation3, SFv was then computed from F;0 \[and\]\[ v\]\[Y\] 0 \[. Values of\]\[ P\] ;max

(normalized to body + carriage seat mass) were determined
from the first mathematical derivation ofequations. Moreover, to test the validity of equation 1, P–v regression P;max

was also computed from this equation (PmaxTH ).

Inclined push-off performance. To validate equation 6, each subject then performed two inclined maximal
push-offs at three sled angles (>) (10-, 20-, and 30- above
the horizontal) with the motor chain disconnected from
the carriage seat, following the same procedures described
above. vTO was determined for each trial as the instantaneous

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

Y), velocity (vY), and power (PY)

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

0 \[and\]\[ v\]\[Y\]

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

0 \[. Values of\]\[ P\]

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

;

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f** **f**

**f** **f** **f** **f** **f** **f** **f** **f** **f**

OPTIMAL FORCE–VELOCITY PROFILE Medicine & Science in Sports & Exercised 315

Copyright © 2012 by the American College of Sports Medicine. Unauthorized reproduction of this article is prohibited.

velocity value when the force signal fell to zero. Push-off
distance (hPO) was determined for each subject by integrating
the velocity signal over time during the push-off phase.

Statistical analyses. All data are presented as mean T
SD. For each subject and each sled angle condition, the
highestvTOmax computed according to equation 6, from vTO reached in the two trials was compared with P;max \[,\]\[ h\]\[PO\]\[,\]

and SFv. After checking distributions normality with the
Shapiro–Wilk test, the difference between vTO and vTOmax
(bias) was computed and tested using a t-test for paired
samples. To complete this comparison, the absolute difference between vTO and vTOmax (absolute bias) was also
calculated as jðvTOmaxjvTOÞv \[j\] TO \[1\]\[j\]\[100 (36). Using the same\]

in P;max \[and\]\[ S\]\[Fv\]\[ at different push-off angles (\]\[>\]\[), each variable\]

being studied separately.

RESULTS

;

;

0 \[,\]\[ v\]\[Y\]

;

;

0 \[,\]\[ F\]

calculated ascomparison method, experimental values of jðvTOmaxjvTOÞv \[j\] TO \[1\]\[j\]\[100 (36). Using the same\] P;max \[were\]

compared with theoretical values (PmaxTH). After checking
the homogeneity of variances, the effect of sled angle was
tested with a one-way ANOVA for repeated measures on
vTO and vTOmax . When a significant effect was detected, a
post hoc Newman–Keuls comparison was used to locate
the significant differences. For all statistical analyses, a
P value of 0.05 was accepted as the level of significance.

Validation of the theoretical approach. Individual
F–v and P–v relationships were well fitted by linear
(r \[2\] = 0.75–0.99, P e 0.012) and second-degree polynomial
(r \[2\] = 0.70–1.00, P e 0.024) regressions, respectively. Figure 1
shows these relationships for two typical subjects with dif-;
ferentferentP;max \[, and\] F P;–maxv \[ S\] profiles (i.e., different \[Fv\]\[capabilities. Mean\]\[ were 0.39\]\[ T\]\[ 0.04 m, 2.78\]\[ T\]\[ SD values of\] F 0 \[,\]\[ v\]\[ T\]\[Y\] 0 \[ 0.63 m\]\[, and\]\[ S\]\[ h\]\[Fv\]\[I\]\[s\]\[PO\]\[j\]\[) and dif-\]\[,\]\[1\]\[ v\]\[, 24.2\]\[Y\] 0 \[,\]\[ F\] ; \[ T\] 0 \[,\]

2.97 NIkg \[j\]\[1\] (or 17.3 T 1.60 NIkg \[j\]\[1\] when normalized to
body + carriage seat mass), 16.34 T 2.26 WIkg \[j\]\[1\] (or 11.78 T
1.80 WIkg \[j\]\[1\] when normalized to body + carriage seat
mass), and j9.33 T 3.31 NIsIm \[j\]\[1\] Ikg \[j\]\[1\] (or j6.64 T
mass), respectively. The difference between2.12 NIsIm \[j\]\[1\] Ikg \[j\]\[1\] when normalized to body + carriage seat P; \[and\]\[ P\]\[max\] TH

max \[capabilities. Mean\]\[ T\]\[ SD values of\]\[ h\]\[PO\]\[,\]\[ v\]\[Y\]

;

;

;

METHODS USED IN THE SIMULATION STUDY

;

The relative influences of Pmax \[and\]\[ S\]\[Fv\]\[ on\]\[ v\]\[TO\] max \[were\]

simulations was obtained from data (analyzed via equation 6. First,determined for differentreported for human maximal lower limb extensions:angles (>). The range of P P;;maxmax v \[values at different push-off\] TO \[and\] max \[ S\] P changes with;max \[Fv\]\[ values used in the\]\[,\]\[ F\] ;0 \[,\]\[ v\]\[Y\] 0 \[) previously\] SFv P were;max

from 10 to 40 WIkg \[j\]\[1\] and SFv until to j40 NIsIm \[j\]\[1\] Ikg \[j\]\[1\]

(32,33,36,43). The effect of hPO on performance, previously
studied and discussed (see Samozino et al. \[37\]), was not
specifically treated here; hPO was set at 0.4 m, which is a
typical value for humans. Then, sensitivity analyses were
performed to assess the respective weight of each variable
plotting relative variations in vTOmax against relative variations

The relative influences of P

mass), respectively. The difference between Pmax \[and\]\[ P\]\[max\] TH

was not significant and very low (absolute bias = 1.81% T
0.76%), which shows the validity of equation 1. Mean T SD
values of vTO and vTOmax, as well as mean values of absolute
bias, are presented in Table 1. For each push-off angle, vTO
and vTOmax were not significantly different, and bias was
j0.05 T 0.17 mIs \[j\]\[1\] (see Figure, Supplemental Digital
Content 3, <http://links.lww.com/MSS/A116>, which shows
bias and limits of agreement in a Bland–Altman plot). On
the other hand, the effect of push-off angle was significant
on both vTO and vTOmax, with differences between every
condition (Table 1).Theoretical simulations. As expected, P;max \[positively\]

affects vTOmax, which is clearly shown in Figure 2 for both
vertical (> = 90-) and horizontal (> = 0-) push-offs. The
withmain original result was the curvilinear changes in SFv for a given P;max \[(Fig. 2). Such variations highlight\] vTOmax

slightly as a function of boththe existence of an optimalgiven P;max \[and\]\[ h\]\[PO\]\[. Moreover,\] SFv P ( \[ S\] ;SFv \[Fv\] optopt) maximizing \[and\]\[values seem to change\]\[ >\]\[ values, ranging\] vTOmax for

max \[and\]\[ >\]\[ values, ranging\]

;

;

;

;

max \[,\]\[ F\]

0 \[,\]\[ v\]\[Y\]

;

;

Theoretical simulations. As expected, P

;

;

;

FIGURE 1—Typical F–v (left panel) and P–v (right panel) relationships for two subjects with different F–v profiles (SFv = jF \[–\]

0 \[/\]\[v\]\[–\] 0 \[) and\]\[ P\]\[–\]

FIGURE 1—Typical F–v (left panel) and P–v (right panel) relationships for two subjects with different F–v profiles (SFv = jF0 \[/\]\[v\]\[–\] 0 \[) and\]\[ P\] max \[values\]

(gray cross). Subject 1 (open circles) presents a lower P \[–\] max \[and an\]\[ F\]\[–\]\[v\]\[ profile more oriented toward force capabilities than subject 2 (\]\[ filled circles\]\[), who\]

presents an F–v profile more oriented toward velocity capabilities.

316 Official Journal of the American College of Sports Medicine <http://www.acsm-msse.org>

Copyright © 2012 by the American College of Sports Medicine. Unauthorized reproduction of this article is prohibited.

TABLE 1. Mean T SD of vTO obtained with experimental and theoretical approaches,
absolute bias between these two approaches, and t-test comparison results.

Absolute
Bias (%)

Theoretical Values

(vTOmax (mIs \[j\]\[1\] )) t-Test

- (-)

Experimental Values

(vTO (mIs \[j\]\[1\] ))

10 2.45 T 0.22 2.43 T 0.18 ns 4.40 T 4.94
20 2.32 T 0.25 \[a\] 2.25 T 0.16 \[a\] ns 6.56 T 5.46
30 2.14 T 0.23 \[ab\] 2.07 T 0.15 \[ab\] ns 5.73 T 3.89

a Significantly different from > = 10-.
b Significantly different from > = 20-.
ns, nonsignificative difference between experimental and theoretical values.

fromin Figure 2. The dependence of j18 to j6 NIsIm \[j\]\[1\] Ikg \[j\]\[1\] for the conditions simulated SFvopt on P;max \[,\]\[ >\]\[, and\]\[ h\]\[PO\]

;

in Figure 2. The dependence of SFvopt on Pmax \[,\]\[ >\]\[, and\]\[ h\]\[PO\]

can be mathematically analyzed: the expression of SFvopt as a
function of these three variables is a real solution canceling
out the first mathematical derivative of vTOmax with respect
to SFv (see appendices, Supplemental Digital Content 1b,
<http://links.lww.com/MSS/A114>, for detailed computationsof SFvopt). Whatever the value of P;max \[,\]\[ S\]\[Fv\] opt \[decreases when\]

;

of SFvopt). Whatever the value of Pmax \[,\]\[ S\]\[Fv\] opt \[decreases when\]

- increases (Fig. 3). For both vertical and horizontal pushoffs, the sensitivity analysis showed thatfluenced by P;max \[than by\]\[ S\]\[Fv\]\[, at least when the\] vTOmax \[ S\] is more in- \[Fv\]\[ reference\]

effects ofvalue is equal to P;max \[and\] S \[ S\] Fv \[Fv\] opt (Fig. 4). Moreover, the respective \[ on\]\[ v\]\[TO\] max \[seem to decrease with de-\]

creasing > (Fig. 4).

;

;

DISCUSSION

listic performance of the lower limbs depends on bothThe original and main findings of this study are that bal- P;max

capabilities and the F–v profile, with the existence of an
individual optimal F–v profile corresponding to the best
balance between force and velocity capabilities. This optimal F–v profile, which can be accurately determined,
depends on some individual characteristics (limb extensionrange, P; \[) and on the afterload involved in the movement\]

;

;

max \[) and on the afterload involved in the movement\]

FIGURE 3—Changes in optimal F–v profile (SFvopt) as a function of
the push-off angle (>) for different P \[–\] max \[values. The\]\[ h\] PO \[is fixed here at\]

0.4 m.

(inertia, inclination). The concept of optimal F–v profile and
the proposed approach make it possible to clarify some
scientific issues previously discussed about the mechanical
capabilities of lower limbs that determine ballistic performance and about the relationships between lower limb
neuromuscular system structure and function. The following
discussion is devoted to detailing these different points.

Validity of the theoretical approach. These findings
were obtained using a theoretical integrative approach based
on fundamental principles of dynamics and on the F–v linear
model characterizing the dynamic mechanical capabilities of
the neuromuscular system during a lower limb extension.
This linear model, as well as the parabolic P–v relationship,
has been well supported and experimentally described for

FIGURE 2—Changes in maximal CM vTO (vTOmax) reached at the end of a lower limb push-off, as a function of the changes in the F–v profile (SFv) for
different P \[–\] max \[values and at two push-off angles (\]\[>\]\[). The\]\[ h\] PO \[is fixed here at 0.4 m. For the vertical push-off (\]\[>\]\[ = 90\]\[-\]\[), the corresponding jump height\]

(obtained from basic ballistic equations) is presented on the additional y axis. Open circles represent the vTOmax reached for an optimal F–v profile
(SFvopt).

OPTIMAL FORCE–VELOCITY PROFILE Medicine & Science in Sports & Exercised 317

Copyright © 2012 by the American College of Sports Medicine. Unauthorized reproduction of this article is prohibited.

FIGURE 4—Sensitivity analyses: relative changes in maximal CM vTO (vTOmax) as a function of the relative variations of P \[–\] max \[and\]\[ F\]\[–\]\[v\]\[ profile (\]\[S\] Fv \[) for\]

two > values. The reference value for P \[–\] max \[is 25 W\]\[I\]\[kg\]\[j\]\[1\]\[ and corresponds to the optimal\]\[ F\]\[–\]\[v\]\[ profile value for\]\[ S\] Fv \[(\]\[j\]\[14.0 for\]\[ >\]\[ = 90\]\[-\]\[ and\]\[ j\]\[8.20 for\]\[ >\]\[ = 0\]\[-\]\[).\]

The hPO is fixed here at 0.4 m. For SFv, the higher the normalized variation, the lower the value because SFv values are only negative and the more
the F–v profile tends toward force capabilities.

multijoint movements (3,33,43,44). The linearity of the F–v
relationship, usually presented as hyperbolic for isolated
muscles (17), is explained by the integrative feature of the
model. The force generator and, in turn, its maximal force(F;0 \[), unloaded velocity (\]\[v\]\[Y\] 0 \[), and power (\]\[P\] ;max \[) refer here to\]

the entire in vivo neuromuscular system involving several
muscles with different mixed fiber composition, architectural characteristics, anatomical joint configuration, level
of neural activation, and specific coordination strategies
(7–9,44). The limits of this theoretical approach have been
previously discussed (37), but the significance and accuracy of its predictions have not been quantified yet. Besidesvalidating equation 1 (P;max \[and\]\[ P\]\[max\] TH \[are very close), the\]

present results showed no differences between predicted
(vTOmax) and measured (vTO) values, associated to a low
absolute bias from 4% to 6.6%. This is within the range of
reproducibility indices previously reported for different
variables (performance, velocity, force, or power) measured during lower limb maximal extensions (3,18). These
results support the validity of the proposed theoretical approach, which was strengthened by the sensibility of both
predicted and experimental values to changes in push-off
angles. Obviously, the accuracy of equation 6 is enhancedwhen muscular properties (P;max \[and\]\[ S\]\[Fv\]\[) are assessed in\]

the same conditions (e.g., joints and muscle groups involved, range of motion) under which the actual performance is studied, as it was done here on the EXER.

Muscular capabilities determining jumping performance.ing jumping performance,Although expected, the importance of Among the muscular characteristics determin- P;max \[has the greatest weight.\] P;max \[in setting bal-\]

listic performance needed to be established, as concluded by
Cronin and Sleivert (12) in their recent review: ‘‘power is
only one aspect that affects performance and it is quite likely
that other strength measures may be equally if not more
important for determining the success of certain tasks.’’ The
present results clearly demonstrate this idea. On the other
hand, the dependence of ballistic performances on muscular

Pmax \[and\]\[ h\]\[PO\]\[), there is an optimal\]\[ F\]\[–\]\[v\]\[ profile that max-\]

imizes performance. The more this F–v profile differs from
the optimal one, the lower the performance in comparison

;

;

power capability brings new insights into the recurrent debate about the role of ‘‘power’’ in impulsive performance,
such as jumping (22,26,42). On the basis of Newton’s second law of motion, some authors stated that jumping performance does not depend on the muscular capability to
develop power but rather on the capability to develop a high
impulse (26,42). Even if fundamental principles of dynamics
directly relate mechanical impulse to vTO (and in turn jumping performance), the capability to generate impulse does not
represent an intrinsic mechanical property of the lower limbneuromuscular system, contrary to P;max \[. It is important to\]

differentiate mechanical outputs (e.g., external force, movement velocity, power output, impulse, mechanical work) frommechanical capabilities of lower limbs (P;max \[,\]\[ v\]\[Y\] 0 \[,\]\[ F\] ;0 \[). On\]

the one hand, mechanical outputs represent the mechanical
entities that can be externally measured during a movement
and are often used to characterize movement dynamics from
a mechanical point of view. On the other hand, mechanical
capabilities of lower limbs characterize the mechanical limits of the neuromuscular function and refer to the theoretical

maximal values of some mechanical outputs that could be
reached by an individual. The proposed theoretical approach
demonstrates that the ability to develop a high impulse
against the ground and, in turn, the ability to reach maximal
CM velocity at the end of a push-off are highly related tothe P;max \[the lower limbs can produce (over a given exten-\]

sion range).That said, the present results show that P;max \[is not the\]

only muscular property involved in jumping performance.Indeed, two individuals with the same P;max \[(and the same\]

hPO) may achieve different performances, be it during a
vertical jump or a horizontal push-off (Fig. 2). These differences are due to their respectivetheir respective ratios between maximal force ( F–v profiles (F;S0Fv \[) and ve-\] ), i.e., to

Plocity (; \[and\] v \[Y\] 0 \[ h\]\[) capabilities. For each individual (given his/her\]\[ F\]\[–\]\[v\]

0 \[), unloaded velocity (\]\[v\]\[Y\]

0 \[), and power (\]\[P\]

;

;

;

;

0 \[,\]\[ F\]

max \[,\]\[ v\]\[Y\]

;

;

;

That said, the present results show that P

;

;

;

;

;

318 Official Journal of the American College of Sports Medicine <http://www.acsm-msse.org>

Copyright © 2012 by the American College of Sports Medicine. Unauthorized reproduction of this article is prohibited.

with the one that could be reached with the same power
capabilities (Fig. 2). The values of SFv observed here (from;
j16.8 to j4.9 NIsIm \[j\]\[1\] Ikg \[j\]\[1\] ) are consistent with; F 0 \[and\] ;

v \[Y\] 0 \[values previously reported (3,32,33,43).\]\[ P\] max \[and\]\[ F\] 0

values were slightly lower than those reported during vertical
push-offs (3,32,33), which is likely due to the specific sitting
position imposed by the EXER compared with the totally
extended hip configuration usually tested. Individuals, notably rugby players, as most of our subjects were, may present
very different F–v profiles, as shown by coefficients of variation forvariation below 20% for SFv of beyond 30% compared with coefficients of P;max \[or\]\[ F\] ;0 \[. Most of these different\]

individual F–v profiles differ from the optimal ones, thus
characterizing unfavorable balances between force and velocity capabilities. Indeed, individual F–v profiles observed in
this study ranged from 36% to 104% of the optimal ones
maximizing vertical jumping performance. Simulations of
equation 6 showed that such unfavorable F–v balances may
be related to differences up to 30% in jump height between
two individuals with similar power capabilities (Figs. 2 and
4). Consequently, we think that the F–v profile represents a
muscular quality that has to be considered attentively not only
by scientists working on muscle function during maximal
efforts but also by coaches for training purposes.

Effect of afterloads on optimal F–v profile. The
optimalacteristics ( F–vh profile depends on some individual char-PO, P;max \[) and on the afterload opposing in\]

motion (inertia, inclination). On the one hand, the F–v profile does affect jumping performances when SFv is expressed
through values normalized to the total moving mass
(NIsIm \[j\]\[1\] Ikg \[j\]\[1\] ), which may be body mass, body mass plus
additional loads, or projectile mass. Thus, the interpretation
of F–v profiles is dependent on the movement considered.
On the other hand, the computation of the optimal F–v
profile also takes account of the total moving mass:function of P;max \[, itself expressed relative to moving mass.\] SFvopt is a

Consequently, for a given athlete, the optimalnot the same for a javelin throw (highmoving mass) and for a shot put (low relative P;max F P;–maxv \[relative to\] profile is \[, see the\]

different curves in Fig. 3). The optimal F–v profile also
depends on the push-off angle and more generally on the
magnitude of the gravity component opposing motion (the
lower the push-off angle, the more the optimal F–v profile is
oriented toward velocity capabilities). Thus, the optimal F–v
profile is not the same when seeking to maximize performance during the first push of a sprint or during a vertical
jump; velocity capabilities are more important in the former
case; force capabilities, in the latter. This is in line with the
theoretical framework proposed by Minetti (28) showing
that power output developed during maximal efforts is less
dependent on muscle strength when the exercise does not
involve gravity, as in horizontal extensions. Such horizontal
(or very horizontally inclined) push-offs are thus especially
limited by the velocity capabilities of lower limbs. The
originality of the present theoretical approach is to allow
the accurate determination of the optimal balance between

force and velocity capabilities (through SFvopt ) according to
movement specificities. The subjects tested here presented
an overall unfavorable balance toward velocity capabilities
for vertical jumps (SFv from 36% to 104% of their respective
SFvopt) and toward force capabilities for horizontal push-offs
(SFv from 66% to 227% of SFvopt ).

F–v profile and athletic training. Assessing F–v
profiles when seeking to identify the optimal balance between force and velocity capabilities may be of interest to set
training loads and regimens, as previously proposed using
power–load relationships (10,20,27,38). Values of SFv allow
comparisons among athletes independently from their powercapabilities (which is not possible from only F;0 \[and\]\[ v\]\[Y\] 0

values) and, thus, to know whether an athlete, as compared
with another one, is characterized by a ‘‘force’’ or a
‘‘velocity’’ profile (Fig. 1). To the best of our knowledge,
only Bosco (2) proposed an index to compare athletes’ F–v
profiles dividing jump height reached with an additional
load (100% of body mass) by unloaded jump height: the
higher this index, the higher the force capabilities compared
with the velocity ones. However, Bosco’s index does not
allow the orientation of training loads for a given athlete
according to his/her own strengths and weaknesses and to
movement specificities. Therefore, we propose the individual value of SFv, expressed relatively to SFvopt, as a good and
practical index to characterize the F–v profile and to design
appropriate training programs. The present results showed
that improving ballistic performance may be achieved
through increasing power capabilities (i.e., shifting F–v
relationships upward and/or to the right \[21\]) and moving
the F–v profile as close to the optimal one as possible. Such
changes in the F–v relationship, notably in its slope, may be
achieved by specific strength training (7,8,21). An athlete
presenting an unfavorable F–v balance in favor of force
(relatively to his/her optimal profile corresponding to target
movement specificities) should improve his/her velocity
capabilities as a priority by training with maximal efforts
and light (e.g.,being close to F G;030% of one repetition maximum, the latter \[) or negative loading, which is often called\]

‘‘ballistic’’ or ‘‘power’’ training (7,8,11,25,27). On the contrary, an athlete with an imbalanced F–v profile oriented
toward velocity should follow a strength training with heavy
loads (975%–80% of one repetition maximum) to increase
his/her force capabilities as a priority (7,8,27). In both cases,it is likely that (i) P;max \[will increase and (ii) the\]\[ F\]\[–\]\[v\]\[ profile\]

will be optimized (i.e., change toward the optimal one),
partly or totally correcting unfavorable F–v balances. As
shown in the present study, these two changes would
both result in a higher performance. The mechanisms underlying these changes in F–v relationships, specific to the
kind of training, include changes in mixed fiber composition, muscle architecture (hypertrophy, pennation angle),
and neural activation (voluntary activation level, firing
frequency, rate of EMG rise, intermuscular coordination strategies) (1,7,15,27). These theoretical findings
support previous experimental results about the velocity (or

;

;

;

0 \[values previously reported (3,32,33,43).\]\[ P\]

max \[and\]\[ F\]

;

;

max \[or\]\[ F\]

;

0 \[and\]\[ v\]\[Y\]

;

;

;

;

;

;

OPTIMAL FORCE–VELOCITY PROFILE Medicine & Science in Sports & Exercised 319

Copyright © 2012 by the American College of Sports Medicine. Unauthorized reproduction of this article is prohibited.

load)-specific changes in performance after training with
light or heavy loads (10,25,27), with the additional originality of controlling the respective effects ofand P;max \[capabilities.\] F–v qualities

F–v profile and optimal load. The proposed approach
brings new insight into the understanding of the relationships between structure and mechanical function of the
lower limb neuromuscular system and, notably, the effect of
specific changes in the F–v relationship on athletic performance. The concept of the F–v profile could be related to the
maximum dynamic output hypothesis proposed and discussed by Jaric and Markovic (20) and supported by recent
studies (6,13,30). Their hypothesis states that the optimal
load-maximizing power output in ballistic movements for
physically active individuals corresponds to their own body
weight and inertia (20). They argued that this optimal load
would be related to the particular design of the muscular
system (notably its mechanical properties), itself influenced
by the actual load individuals regularly overcome during
their daily activities. They pointed out, however, that the
different evidences provided needed to be supported by
theoretical frameworks describing the general aspects of theneuromuscular system’s ability to provide the P;max \[output\]

against a particular load. This may be done using the theoretical approach proposed here. Indeed, the slope of therelationship and, thus, the ratio between F;0 \[and\]\[ v\]\[Y\] 0 \[are di-\] F–v

rectly related to the optimal velocity and force-maximizing
power output and so to the corresponding optimal load.
From F–v and P–v relationships (Fig. 1), the higher the v \[Y\] 0 \[,\]

the higher the optimal velocity and the lower the optimalload. Conversely, high F;0 \[values are associated with high\]

optimal loads. Consequently, the optimal load corresponds
to the mass and inertia of the body only for individuals de-veloping their individual P;max \[during an unloaded vertical\]

jump. Because (i) maximal jump height changes withprofile for a given P;max \[(Fig. 2, left panel) and (ii) jump\] F–v

height and power output (relative to body mass) developed
during a vertical jump are positively related (36), the power

output developed during an unloaded maximal jump depends on the F–v profile. Consequently, jumping performance depends directly on the mean power output developed
during push-off (for a givenmaximized by both maximizing hPO P;), and the latter can bemax \[and optimizing the\]

F–v profile. This is illustrated in Figure 5, which shows the
power output developed during a vertical jump (expressedrelatively to P;max \[) according to the\]\[ F\]\[–\]\[v\]\[ profile expressed\]

relatively to the optimal one (power output was computed
from equations 6 and 9 of Samozino et al. (36), see appendices for more details, Supplemental Digital Content 1c,
<http://links.lww.com/MSS/A114>). An optimali.e., an optimal balance betweenvelopment of P;max \[during an unloaded jump (Fig. 5, left\] F;0 \[and\]\[ v\]\[Y\] 0 \[, allows the de-\] F–v profile,

panel) and thus maximization of jumping performance
(Fig. 5, right panel). Consequently, the body mass represents
the optimal load for individuals with optimal F–v profiles.
An athlete with an unfavorablepower output lower thanSuch an athlete would produce P;max P \[during an unloaded jump.\] F;max–v balance develops a \[against a load lower\]

than body mass if he/she presents a velocity profile and
higher than body mass in the case of a force profile.
The present theoretical framework may help to explain and
understand the possible interindividual differences in optimal load previously observed, discussed, and debated
(6,20,24,30,31,39). The influence of training history recently proposed supports our findings because training
background specificities directly affect the F–v profile
(8,10,27), which influences the optimal load (39). This is in
line with the maximum dynamic output hypothesis stating
that strength-trained athletes (with high force capabilities)
present optimal loads higher than their body mass (20,39).
In animals and humans, the lower limbs’ neuromuscular
system is likely designed to work optimally against loads
usually supported and mobilized (20,23). Consequently,
animals would naturally present F–v profiles optimizing
ballistic performance such as horizontal jumps, when these
latter represent their main survival behavior.

;

;

;

;

0 \[and\]\[ v\]\[Y\]

;

;

;

;

;

0 \[and\]\[ v\]\[Y\]

;

;

;

FIGURE 5—Left panel: changes in power output developed during a vertical jump (expressed in %P \[–\] max \[) with changes in\]\[ F\]\[–\]\[v\]\[ profile (\]\[S\] Fv \[, expressed in\]

%SFvopt). Right panel: effect of the power output developed during a vertical jump (expressed in %P \[–\] max \[) on the jump height reached (expressed\]

relatively to the jump height that could be reached, should the F–v profile be optimal). Values of P \[–\] max \[and\]\[ h\] PO \[were fixed here at 25 W\]\[I\]\[kg\]\[j\]\[1\]\[ and 0.4 m,\]

respectively.

320 Official Journal of the American College of Sports Medicine <http://www.acsm-msse.org>

Copyright © 2012 by the American College of Sports Medicine. Unauthorized reproduction of this article is prohibited.

CONCLUSIONS

by theBallistic performance is mostly determined not only P;max \[lower limbs can generate but also by the\]\[ F\]\[–\]\[v\]

mechanical profile characterizing the ratio between maximal
force capabilities and maximal unloaded extension velocity.
This F–v profile of lower limbs, independent from power
capabilities, may be optimized to maximize performance.
Altius is neither citius nor fortius but an optimal balance
between the two. This optimal F–v profile depends on individual and movement specificities, notably on the afterload involved (inertia and gravity): the lower the afterload,
the more the optimal F–v profile will be oriented toward
velocity capabilities. Considering F–v profile may help better
understand the relationships between neuromuscular system
mechanical properties and functional performance, notably
to optimize sport performance and training. This original me

REFERENCES

1. Bobbert MF, Van Soest AJ. Effects of muscle strengthening on

vertical jump height: a simulation study. Med Sci Sports Exerc.
1994;26(8):1012–20.

2. Bosco C. La Valutazione della Forza con il Test di Bosco

\[Strength Assessment with the Bosco’s Test\]. Rome (Italy): Societa
Sampa Sportiva; 1992. p. 56–7.
3\. Bosco C, Belli A, Astrua M, et al. A dynamometer for evaluation

of dynamic muscle work. Eur J Appl Physiol Occup Physiol. 1995;
70(5):379–86.
4\. Cormie P, McBride JM, McCaulley GO. Power–time, force–time,

and velocity–time curve analysis of the countermovement jump:
impact of training. J Strength Cond Res. 2009;23(1):177–86.
5\. Cormie P, McCaulley GO, McBride JM. Power versus strength–

power jump squat training: influence on the load–power relationship.
Med Sci Sports Exerc. 2007;39(6):996–1003.
6\. Cormie P, McCaulley GO, Triplett NT, McBride JM. Optimal

loading for maximal power output during lower-body resistance
exercises. Med Sci Sports Exerc. 2007;39(2):340–9.
7\. Cormie P, McGuigan MR, Newton RU. Adaptations in athletic

performance after ballistic power versus strength training. Med Sci
Sports Exerc. 2010;42(8):1582–98.
8\. Cormie P, McGuigan MR, Newton RU. Influence of strength on

magnitude and mechanisms of adaptation to power training. Med
Sci Sports Exerc. 2010;42(8):1566–81.
9\. Cormie P, McGuigan MR, Newton RU. Developing maximal

neuromuscular power: part 1—biological basis of maximal power
production. Sports Med. 2011;41(1):17–38.
10\. Cormie P, McGuigan MR, Newton RU. Developing maximal

neuromuscular power: part 2—training considerations for improving maximal power production. Sports Med. 2011;41(2):125–46.
11\. Cronin J, McNair PJ, Marshall RN. Velocity specificity, combi
nation training and sport specific tasks. J Sci Med Sport. 2001;4(2):
168–78.

12. Cronin J, Sleivert G. Challenges in understanding the influence

of maximal power training on improving athletic performance.
Sports Med. 2005;35(3):213–34.
13\. Dayne AM, McBride JM, Nuzzo JL, Triplett NT, Skinner J,

Burr A. Power output in the jump squat in adolescent male athletes. J Strength Cond Res. 2011;25(3):585–9.
14\. Frost DM, Cronin J, Newton RU. A biomechanical evaluation of

resistance: fundamental concepts for training and sports performance. Sports Med. 2010;40(4):303–26.

chanical quality was put forward by a theoretical integrative
approach and validated here from comparisons between
theoretically predicted performances and experimental measurements during jumping. This approach was discussed here
for lower limb extensions, but the results may be also applied to other multijoint muscular efforts, such as upper limb
ballistic movements, or more complex movements such as
sprint running.

The authors thank Alberto Botter (Udine Rugby Football Club) for
his help in recruitment of the subjects tested and the subjects for
their ‘‘explosive’’ implication in the protocol.

No funding for this study from the National Institutes of Health,
Wellcome Trust, Howard Hughes Medical Institute, or others was
received.

The authors declare that they have no conflict of interest.
The results of the present study do not constitute endorsement by
the American College of Sports Medicine.

15. Ha¨kkinen K, Komi PV, Ale´n M. Effect of explosive type strength

training on isometric force– and relaxation–time, electromyographic
and muscle fibre characteristics of leg extensor muscles. Acta
Physiol Scand. 1985;125(4):587–600.
16\. Harris NK, Cronin JB, Hopkins WG, Hansen KT. Squat jump

training at maximal power loads vs. heavy loads: effect on sprint
ability. J Strength Cond Res. 2008;22(6):1742–9.
17\. Hill AV. The heat of shortening and the dynamic constants of

muscle. Proc R Soc Lond B Biol Sci. 1938;126B:136–95.
18\. Hopkins WG, Schabort EJ, Hawley JA. Reliability of power in

physical performance tests. Sports Med. 2001;31(3):211–34.
19\. James RS, Navas CA, Herrel A. How important are skeletal muscle

mechanics in setting limits on jumping performance? J Exp Biol.
2007;210(Pt 6):923–33.
20\. Jaric S, Markovic G. Leg muscles design: the maximum dynamic

output hypothesis. Med Sci Sports Exerc. 2009;41(4):780–7.
21\. Kaneko M, Fuchimoto T, Toji H, Suei K. Training effect of dif
ferent loads on the force–velocity relationship and mechanical power
output in human muscle. Scand J Sports Sci. 1983;5(2):50–5.
22\. Knudson DV. Correcting the use of the term ‘‘power’’ in the strength

and conditioning literature. J Strength Cond Res. 2009;23(6):1902–8.
23\. Lutz GJ, Rome LC. Built for jumping: the design of the frog

muscular system. Science. 1994;263(5145):370–2.
24\. Markovic G, Jaric S. Positive and negative loading and mechanical

output in maximum vertical jumping. Med Sci Sports Exerc.
2007;39(10):1757–64.
25\. Markovic G, Vuk S, Jaric S. Effects of jump training with negative

versus positive loading on jumping mechanics. Int J Sports Med.
2011;32(5):365–72.
26\. McBride JM, Kirby TJ, Haines TL, Skinner J. Relationship be
tween relative net vertical impulse and jump height in jump squats
performed to various squat depths and with various loads. Int J
Sports Physiol Perform. 2010;5(4):484–96.
27\. McBride JM, Triplett-McBride T, Davie A, Newton RU. The effect

of heavy- vs. light-load jump squats on the development of strength,
power, and speed. J Strength Cond Res. 2002;16(1):75–82.
28\. Minetti AE. On the mechanical power of joint extensions as af
fected by the change in muscle force (or cross-sectional area),
ceteris paribus. Eur J Appl Physiol. 2002;86(4):363–9.
29\. Newton RU, Kraemer WJ. Developing explosive muscular power:

implications for a mixed methods training strategy. Strength Cond.
1994;16(5):20–31.

OPTIMAL FORCE–VELOCITY PROFILE Medicine & Science in Sports & Exercised 321

Copyright © 2012 by the American College of Sports Medicine. Unauthorized reproduction of this article is prohibited.

30. Nuzzo JL, McBride JM, Dayne AM, Israetel MA, Dumke CL,

Triplett NT. Testing of the maximal dynamic output hypothesis in
trained and untrained subjects. J Strength Cond Res. 2010;24(5):
1269–76.

31. Pazin N, Bozic P, Bobana B, Nedeljkovic A, Jaric S. Optimum

loading for maximizing muscle power output: the effect of training
history. Eur J Appl Physiol. 2011;111(9):2123–30.
32\. Rahmani A, Locatelli E, Lacour JR. Differences in morphology

and force/velocity relationship between Senegalese and Italian
sprinters. Eur J Appl Physiol. 2004;91(4):399–405.
33\. Rahmani A, Viale F, Dalleau G, Lacour JR. Force/velocity and

power/velocity relationships in squat exercise. Eur J Appl Physiol.
2001;84(3):227–32.
34\. Rejc E, Lazzer S, Antonutto G, Isola M, di Prampero PE. Bilat
eral deficit and EMG activity during explosive lower limb contractions
against different overloads. Eur J Appl Physiol. 2010;108(1):157–65.
35\. Samozino P, Horvais N, Hintzy F. Why does power output de
crease at high pedaling rates during sprint cycling? Med Sci Sports
Exerc. 2007;39(4):680–7.
36\. Samozino P, Morin JB, Hintzy F, Belli A. A simple method

for measuring force, velocity and power output during squat jump.
J Biomech. 2008;41(14):2940–5.
37\. Samozino P, Morin JB, Hintzy F, Belli A. Jumping ability: a the
oretical integrative approach. J Theor Biol. 2010;264(1):11–8.

NOTATION

38. Sheppard J, Cormack S, Taylor K, McGuigan M, Newton R.

Assessing the force–velocity characteristics of the leg extensors
in well-trained athletes: the incremental load power profile.
J Strength Cond Res. 2008;22(4):1320–6.

39. Stone MH, O’Bryant HS, McCoy L, Coglianese R, Lehmkuhl M,

Schilling B. Power and maximum strength relationships during
performance of dynamic and static weighted jumps. J Strength
Cond Res. 2003;17(1):140–7.

40. Vandewalle H, Peres G, Heller J, Panel J, Monod H. Force–

velocity relationship and maximal power on a cycle ergometer.
Correlation with the height of a vertical jump. Eur J Appl Physiol
Occup Physiol. 1987;56(6):650–6.

41. Vandewalle H, Peres G, Monod H. Standard anaerobic exercise

tests. Sports Med. 1987;4(4):268–89.

42. Winter EM. Jumping: power or impulse. Med Sci Sports Exerc.

2005;37(3):523–4.
43\. Yamauchi J, Ishii N. Relations between force–velocity character
istics of the knee–hip extension movement and vertical jump performance. J Strength Cond Res. 2007;21(3):703–9.
44\. Yamauchi J, Mishima C, Nakayama S, Ishii N. Force–velocity,

force–power relationships of bilateral and unilateral leg multi-joint
movements in young and elderly women. J Biomech. 2009;42(13):
2151–7.

CM body center of mass
m body mass or moving mass (kg)
FgY gravitational acceleration on Earth (9.81 mIs \[j\]\[2\] )

FY mean external force developed over push-off along the push-off axis (relative to moving mass (NIkg \[j\]\[1\] ))

Pv \[Y\] Y mean CM velocity over push-off along the push-off axis (mIs \[j\]\[1\] ) I \[j\]\[1\]

PF;Y mean power output developed over push-off (relative to moving mass (Wtheoretical maximal value of FY Ikg \[j\]\[1\] ))

F;0 theoretical maximal value of FY that lower limbs can produce during one extension at a theoretical null vY (relative to moving mass (NIkgj1))

v \[Y\] theoretical maximal value of v \[Y\]

;

0 theoretical maximal value of F

Pv \[Y\] ;0 theoretical maximal value ofmaximal PY v \[Y\] at which lower limbs can extend during one extension under the influence of muscle action in a theoretical unloaded condition (mI j1 Is \[j\]\[1\] )

PP;maxmaxTH maximaltheoretical value of PY that lower limbs can produce during a push-off (W P;max \[estimated from equation 1 (W\]\[I\]\[kg\]\[j\]\[1\]\[)\] Ikgj1)

;

max maximal P

PmaxTH theoretical value of P;max \[estimated from equation 1 (W\]\[I\]\[kg\]\[j\]\[1\]\[)\]

hPO push-off distance determined by lower limb extension range (m)
vTO CM velocity at takeoff (mIs \[j\]\[1\] )
vTOmax maximal vTO an individual can reach (mIs \[j\]\[1\] )

- push-off angle with respect to the horizontal (-)
  SSFvFvopt slope of linearoptimal value of F S–vFv relationship (N maximizing vITOsImmax \[j\] for given values of \[1\] Ikg \[j\]\[1\] ) P;max

;

max \[and\]\[ h\]\[PO\]\[ (N\]\[I\]\[s\]\[I\]\[m\]\[j\]\[1\]\[I\]\[kg\]\[j\]\[1\]\[)\]

;

322 Official Journal of the American College of Sports Medicine <http://www.acsm-msse.org>

Copyright © 2012 by the American College of Sports Medicine. Unauthorized reproduction of this article is prohibited.
